=====
Kogia
=====

Kogia is a toolbox for Django.

.. image:: https://img.shields.io/pypi/l/kogia
   :alt: Apache-2.0
   :target: https://gitlab.com/pascalpepe/kogia/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/v/kogia
   :alt: PyPI
   :target: https://pypi.org/project/kogia/

.. image:: https://img.shields.io/pypi/pyversions/kogia
   :alt: Python
   :target: https://pypi.org/project/kogia/

.. image:: https://img.shields.io/pypi/djversions/kogia?label=django
   :alt: Django
   :target: https://pypi.org/project/kogia/

.. image:: https://gitlab.com/pascalpepe/kogia/badges/main/pipeline.svg
   :alt: Pipeline
   :target: https://gitlab.com/pascalpepe/kogia/-/pipelines


Status
======

1. This project is still in its initial development stage. Anything may change
   at any time.
2. "Kogia" is a code name. The project will be renamed after its first stable
   release. Everything else will stay the same.


Supported versions of Python and Django
=======================================

======= ===================================
Django  Python
======= ===================================
2.2 LTS 3.5, 3.6, 3.7, 3.8 (added in 2.2.8)
------- -----------------------------------
3.1     3.6, 3.7, 3.8
======= ===================================


Documentation
=============

The documentation of this project is available at
https://pascalpepe.gitlab.io/kogia.

- `Getting started <https://pascalpepe.gitlab.io/kogia/getting-started.html>`_
- `Module references <https://pascalpepe.gitlab.io/kogia/references/index.html>`_
- `Release notes <https://pascalpepe.gitlab.io/kogia/releases/index.html>`_


Can I contribute?
=================

Please do! This project is open source, so contributions are very welcome! If
you don't know how to proceed, here are some `contribution guidelines <https://gitlab.com/pascalpepe/kogia/-/blob/main/CONTRIBUTING.md>`_ that might help.


Copyrights and licenses
=======================

Source code
-----------

Kogia is licensed under the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.

Documentation
-------------

The documentation of Kogia is licensed under a
Creative Commons Attribution-ShareAlike 4.0 International License
(`CC-BY-SA-4.0 <https://creativecommons.org/licenses/by-sa/4.0/>`_).

Code samples and snippets found in the documentation are licensed under
the Apache License, Version 2.0, same as the project source code.

Logo
----

The Kogia logo is Copyright (C) 2017-2020 Pascal Pepe.
See https://gitlab.com/pascalpepe/assets for more information.
